@@ -209,7 +209,8 @@ class WeatherBitApiClient:
                 dewpt=base_data["dewpt"],
                 pop=base_data["pop"],
                 weather_icon=base_data["weather"]["icon"],
-                condition=self.cnv.condition_from_code(base_data["weather"]["code"], self._is_night),
+                condition=self.cnv.condition_from_code(base_data["weather"]["code"], self._is_night, False),
+                alt_condition=self.cnv.condition_from_code(base_data["weather"]["code"], self._is_night, True),
                 weather_text=base_data["weather"]["description"],
                 vis=base_data["vis"],
                 precip=base_data["precip"],
